@@ -25,4 +25,4 @@
  *
  */
 
-let HAVE_UNOCONV = 0
\ No newline at end of file
+let HAVE_UNOCONV = 0;
\ No newline at end of file
